package market.Qms.metallurgy.mapper;

import java.util.List;

import market.Qms.metallurgy.vo.ComMscPlineRSpec;

import com.hnshituo.orm.GenericMapper;
public interface ComMscPlineRSpecMapper extends GenericMapper<ComMscPlineRSpec, String> {

	/**
	 * 获取与产线适用信息
	 * @param condition
	 * @return
	 */
	List<ComMscPlineRSpec> GetMscPlineRSpecByPlineCode(String condition);
	
	List<ComMscPlineRSpec> doQueryWebBySQL(int i, int j, String passName, String wellName, String state);

	int doQueryWebBySQLCount(String passName, String wellName, String state);
	
	Integer GetMaxIndexNo();
	
	void doExitDuct(String id);
	
	void doExitsteels(String id);
	
	int doQueryById(String s);
	
	int doQueryByIds(String s,int ss);
	
	void doUpdateHf(String id);
	
	

}
